@@ -95,7 +95,7 @@ class Crystal:
         ) + "".join([chr(ord("i") + i) for i in range(tensor_order)])
         path_string = input_string + "->" + output_string
         result_list = [
-            np.einsum(path_string, *[rho for i in range(tensor_order)])
+            np.einsum(path_string, *[rho for i in range(tensor_order)], optimize = 'greedy')
             for rho in self.geometry.point_group.group_matrices
         ]
         result = np.sum(result_list, axis=0) / self.geometry.point_group.cardinality
@@ -206,7 +206,7 @@ class Crystal:
                 momentum_matrix_beta = self.band_structure.momentum_matrix[beta, use_bands, use_bands,:],
                 k_weights = self.band_structure.k_sample.weights,
                 integration_constant = self._k_int_const)
-        return np.einsum('ijab,abw->wij',transformation_matrix, sigma_IBZ)
+        return np.einsum('ijab,abw->wij',transformation_matrix, sigma_IBZ, optimize = 'greedy')
 
     def generalized_drude_weight(
         self,
@@ -241,6 +241,7 @@ class Crystal:
             np.einsum(
                 "annk->ank",
                 self.band_structure.momentum_matrix[:, use_bands, use_bands, :],
+                optimize = 'greedy'
             )
         )
         transformation_matrix, nonzero_components = self.get_transformation_matrix(
@@ -285,7 +286,7 @@ class Crystal:
             values of the intraband conductivity
         """        
         D = self.generalized_drude_weight(use_bands=use_bands)
-        return 1j * np.einsum('ij,w->wij',D, 1./(omega + 1j * self.eta))
+        return 1j * np.einsum('ij,w->wij',D, 1./(omega + 1j * self.eta), optimize = 'greedy')
 
     def local_conductivity(self, omega, use_bands=slice(None)):
         """local conductivity
